<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    ユーザ作成コンテンツ
 * @author     株式会社 毎日メディアサービス
 * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: user_contentTopWidgetContainer.php 2971 2010-03-25 05:06:34Z fishbone $
 * @link       http://www.m-media.co.jp
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/user_contentBaseWidgetContainer.php');

class user_contentTopWidgetContainer extends user_contentBaseWidgetContainer
{
	private $langId;		// 言語ID
	private $roomId;		// ルームID
	private $contentArray = array();	// 現在のルームに対応したコンテンツ情報
	private $isTabCreated;	// タブが作成されたかどうか
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{
		$act = $request->trimValueOf('act');
		return 'main.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		$this->langId = $this->gEnv->getDefaultLanguage();		// デフォルト言語
		$act = $request->trimValueOf('act');
		$this->roomId = $request->trimValueOf(M3_REQUEST_PARAM_ROOM_ID);
		if (empty($this->roomId)) $this->roomId = $request->trimValueOf(M3_REQUEST_PARAM_ROOM_ID_SHORT);		// 略式ルームID
		
		// 公開可能なルームかどうかチェック
		$ret = $this->_db->isActiveRoom($this->roomId);
		if (!$ret){
			$this->SetMsg(self::MSG_APP_ERR, "該当するデータがありません");
			
			// タブを非表示にする
			$this->tmpl->setAttribute('tab_area', 'visibility', 'hidden');
			return;
		}
		
		// ルームIDに対応したコンテンツをすべて取得
		$this->contentArray = $this->getAllContent($this->roomId, $this->langId);
		
		// タブの作成
		$this->_db->getAllVisibleTabs($this->langId, array($this, 'itemsLoop'));
		if (!$this->isTabCreated) $this->cancelParse();
	}
	/**
	 * タブ項目をテンプレートに設定する
	 *
	 * @param int		$index			行番号
	 * @param array		$fetchedRow		取得行
	 * @param object	$param			任意使用パラメータ
	 * @return bool						trueを返すとループ続行。falseを返すとその時点で終了。
	 */
	function itemsLoop($index, $fetchedRow)
	{
		$row = array(
			'name' => $this->convertToDispString($fetchedRow['ub_name']),		// タブタイトル
			'href' => '#' . $fetchedRow['ub_id']		// タブ参照先
		);
		$this->tmpl->addVars('tablist', $row);
		$this->tmpl->parseTemplate('tablist', 'a');
		
		// タブ内容を作成
		$content = $fetchedRow['ub_template_html'];
		
		// コンテンツ項目IDを取得
		$useItemArray = array();
		$useItem = $fetchedRow['ub_use_item_id'];
		if (!empty($useItem)){
			$useItemArray = explode(',', $useItem);
		}
			
		// タブにコンテンツデータを埋め込む
		for ($i = 0; $i < count($useItemArray); $i++){
			$itemId = $useItemArray[$i];
			$keyTag = M3_TAG_START . M3_TAG_MACRO_ITEM_KEY . $itemId . M3_TAG_END;// 埋め込みタグ

			$contentInfo = $this->contentArray[$itemId];
			if (isset($contentInfo)){	
				$contentData = $contentInfo['uc_data'];
				
				// テキスト、数値のときは文字エスケープ処理
				if ($contentInfo['ui_type'] != 0){
					$contentData = $this->convertToDispString($contentData);
				}
			} else {
				$contentData = '';
			}
			// 埋め込みタグ変換
			$content = str_replace($keyTag, $contentData, $content);
		}

		$row = array(
			'panel_id' => $fetchedRow['ub_id'],		// タブID
			'content' => $content		// タブ内容
		);
		$this->tmpl->addVars('panellist', $row);
		$this->tmpl->parseTemplate('panellist', 'a');
		
		// タブ情報が取得できた
		$this->isTabCreated = true;
		return true;
	}
	/**
	 * すべてのコンテンツ項目を取得
	 *
	 * @return array			コンテンツ項目IDをキーにしたコンテンツ項目レコードの連想配列
	 */
	function getAllContent($roomId, $langId)
	{
		$destArray = array();
		
		$ret = $this->_db->getAllContentsByRoomId($roomId, $langId, $rows);
		if ($ret){
			$count = count($rows);
			for ($i = 0; $i < $count; $i++){
				$key = $rows[$i]['uc_id'];
				$destArray[$key] = $rows[$i];
			}
		}
		return $destArray;
	}
}
?>
